@@ -593,22 +593,25 @@ class PostgresSourceConnector(C8Connector):
 
     @staticmethod
     def get_config(integration: dict) -> dict:
-        return {
-            # Required config keys
-            'host': integration['host'],
-            'user': integration['user'],
-            'password': integration['password'],
-            'port': integration['port'],
-            'dbname': integration['dbname'],
-            # Optional config keys
-            'tap_id': integration.get('tap_id'),
-            'filter_schemas': integration.get('filter_schemas'),
-            'debug_lsn': integration.get('debug_lsn') == 'true',
-            'max_run_seconds': integration.get('max_run_seconds', 43200),
-            'break_at_end_lsn': integration.get('break_at_end_lsn', True),
-            'logical_poll_total_seconds': float(integration.get('logical_poll_total_seconds', 0)),
-            'use_secondary': integration.get('use_secondary', False),
-        }
+        try:
+            return {
+                # Required config keys
+                'host': integration['host'],
+                'user': integration['user'],
+                'password': integration['password'],
+                'port': integration['port'],
+                'dbname': integration['dbname'],
+                # Optional config keys
+                'tap_id': integration.get('tap_id'),
+                'filter_schemas': integration.get('filter_schemas'),
+                'debug_lsn': integration.get('debug_lsn') == 'true',
+                'max_run_seconds': integration.get('max_run_seconds', 43200),
+                'break_at_end_lsn': integration.get('break_at_end_lsn', True),
+                'logical_poll_total_seconds': float(integration.get('logical_poll_total_seconds', 0)),
+                'use_secondary': integration.get('use_secondary', False),
+            }
+        except KeyError as e:
+            raise KeyError(f'Integration property `{e}` not found.')
 
 
 def main():
